//////////////////////////////////////////////////////////////////////////////////
// Module	 : sx17core.h														//
// Function  : Include for Sensoray 617 application and driver projects.	//
// Copyright : (C) Sensoray 2003												//
//////////////////////////////////////////////////////////////////////////////////

#ifndef DEF_SX17CORE_H
#define DEF_SX17CORE_H

// ioctl constants ----------------------------------------------------

// Core Constants -----------------------------------------------------

#define MAX_BOARDS					4			// Maximum number of boards supported by the core.
#define	CAPTION_LENGTH				64			//caption length (char's)


// Types --------------------------------------------------------------------
typedef int							HBD;		// Logical handle to X16 board.

// OS-independent functions implemented in sx16core.o -----------------------
int		 			SX17CORE_board_init 			(HBD board, unsigned long base_adrs );
void 				SX17CORE_board_close			(HBD board);
int 				SX17CORE_setmode 				(HBD board, MODE *mode);
void				SX17CORE_set_bufrs 				(MODE *mode, SDATA617 *sd617);
void 				SX17CORE_irq_disable 			(HBD board);
void 				SX17CORE_irq_enable 			(HBD board);
ULONG 				SX17CORE_irq_check 				(HBD board);
ULONG 				SX17CORE_jpeg_status 			(HBD board, ULONG *size);
ULONG 				SX17CORE_bmp_status 			(HBD board);
ULONG 				SX17CORE_get_compfactor 		(HBD board);
void 				SX17CORE_set_i2c_chan 			(HBD board, int chan);
ECODE 				SX17CORE_read_decoder_status 	(HBD board, int chan, unsigned long *status);
void 				SX17CORE_start		 			(HBD board, ICOMMAND *icmd, char *caption);
ECODE 				SX17CORE_setXPs 				(HBD board, void *intdata);
ULONG 				SX17CORE_set_vout 				(HBD board, ULONG cmd_vxp, ULONG sys_vxp);
void 				SX17CORE_StartRPS 				(HBD board, ULONG jpgrps, ULONG bmprps);
ECODE				SX17CORE_i2c_ops 				(HBD board, INT_DATA *intdata);
void 				SX17CORE_dbg 					(HBD board, int n);

// Error codes
#define		ERR_DEVICE_NOT_FOUND    2       //no 617 boards found
#define		ERR_SELECT_DEVICE		3		//selected board not found
#define		ERR_MEM_ALLOC			4		//memory allocation error
#define		ERR_MEM_LOCK			5		//DMA buffer lock error
#define		ERR_I2CINIT_BUSY		6		//internal I2C bus initialization error
#define		ERR_I2CINIT_ERR			7		//internal I2C bus initialization error
#define		ERR_TIMEOUT				8		//internal access timeout
#define		ERR_I2C					13		//internal I2C bus error
#define		ERR_I2CTO				14		//internal I2C timeout
#define		ERR_EEPROM				15		//EEPROM programming error
#define		ERR_XPTO				16		//internal crosspoint switch timeout
#define		ERR_SRAM				17		//error loading SRAM
#define		ERR_ILLEGAL_MODE		18		//illegal value in MODE structure
#define		ERR_INTERNAL_OBJ		19		//internal oblect allocation error
#define		ERR_ACQ_TIMEOUT			20		//acquisition timeout
#define		ERR_INTERRUPT			21		//interrupt initialization error
#define		ERR_ILLEGAL_INDEX		24		//illegal board index
#define		ERR_PCI					25		//PCI access error
#define     ERR_BOARDADDR           26      //board address mapping failed
#define     ERR_FIFOEMPTY           30      //data FIFO empty


#endif		// #ifndef DEF_SX17CORE_H

