///////////////////////////////////////////////////////////////////////////////////////////////////
// Module   : sx17mod.h
///////////////////////////////////////////////////////////////////////////////////////////////////

typedef unsigned char		UCHAR;
typedef unsigned short		USHORT;
typedef unsigned long		ULONG;
typedef int					ECODE;
typedef int					BOOL;
typedef unsigned int		UINT;

// Internal data structures ---------------------------
typedef struct {
	ULONG					ldata;					//data buffer addr
	ULONG					spt;					//page table start address (used to free mem)
	ULONG					srps;					//RPS start address (used to free mem)
	ULONG					lpt;					//page table addr
	ULONG					lrps;					//RPS addr
	ULONG					ppt;					//page table phys (bus) addr
	ULONG					prps;					//RPS phys (bus) addr
} DATABUF;

typedef struct {
	int						busy;					//busy flag
	DATABUF					bmp;					//bitmap data
	DATABUF					jpg;					//jpeg data
} SBUF617;

typedef struct {
	void					*kbuf;					// buffer mapped with mmap (rounded up to page start)
	void					*kbufstart;				// buffer mapped with mmap (original, used to free)
	SBUF617					sbuf[SYS_BUFS];			// individual buffer data
	OFFSET					oset[SYS_BUFS];			// individual buffer offsets
} SDATA617;

typedef struct {
    int     	chan;           //decoder #
    COMMAND 	cmd;            //COMMAND struct
} ICOMMAND;


//FIFO element union. Allows creating command, buffer and caption FIFO's.
typedef union {
	BUFFER 		buffer;
	COMMAND 	command;
    ICOMMAND 	icommand;
	char 		caption[65];
} FIFOELEMENT;

//	FIFO structure
typedef struct {
	atomic_t	contents;					//	current number of elements stored;
	int 		size;						//	FIFO size (elements);
	FIFOELEMENT *read;						//	read pointer;
	FIFOELEMENT *write;						//	write pointer;
	FIFOELEMENT *start;						//	FIFO data area start pointer;
	FIFOELEMENT *end;						//	last element pointer;
} FIFO;

//Data used by interrupt handler
typedef struct {							//decoder mode
    int         bright;		                //  brightness setting for captured image
    int         contrast;   		        //  contrast setting for captured image
    int         sat;                		//  saturation setting for captured image
    int         hue;                    	//  hue setting for captured image
} DECMODE;

typedef struct {
	FIFOELEMENT	bfr;						//	working BUFFER
	FIFOELEMENT	icmd;						//	current COMMAND
	FIFOELEMENT	old_icmd;					//	previous COMMAND
	FIFOELEMENT	caption;					//	caption
	int			bi;							//	buffer index
	int			started;					//	"capture started" flag
	ULONG		xpdata;						//	inp crosspoint switch state
	ULONG		vxp;						//	out (video) crosspoint switch state
    ULONG		dioin;                  	//  digital i/o read (in) data
	ULONG		videostatus;				//	"video present" status
	DECMODE		decmode[4];					//	decoder modes (for 4 decoders)
    int         skip4;                      //  1st 4 captured frames must be skipped
} INT_DATA;

//Constants
#define CAPTURE_ST_INC				1		//	"incomplete" capture
#define CAPTURE_ST_ZERR				2		//	JPEG error
#define VIDEO_NOT_PRESENT			0x40	//	mask (1 in masked bit means no video)

#define XP_INIT					0xaaaa0123		//initial xp setting: inp's 1-4 connected
#define VXP_INIT				0xaaaa0123		//initial xp setting: inp's 1-4 connected

#define	TIMESTAMPLENGTH			    8		//00:00:00
#define	DATESTAMPLENGTH			    11		//2005-02-10 plus 1 space

// OS-dependent functions, which are basically wrappers for kernel-supplied functions.
void 			SX17MOD_xdelay (int us);						//wrapper for udelay(x)
void            SX17MOD_TranslateCaption (int index, char *pCaptionOut, char *pCaptionIn, int chan, int offset);
